summaryrefslogtreecommitdiffstats
path: root/doxygen.sh
diff options
context:
space:
mode:
authorMichele Calgaro <michele.calgaro@yahoo.it>2018-09-08 18:51:48 +0900
committerSlávek Banko <slavek.banko@axis.cz>2018-09-16 17:59:45 +0200
commit7ed4760de47e51dc2148c6b1b4aecbcfcf05eb3f (patch)
tree75e76d76f78c2f505bf9d2af8c0f3aed8567962c /doxygen.sh
parent75306d2d1fe3eea200549805583bc9842c5ee172 (diff)
downloadadmin-7ed4760de47e51dc2148c6b1b4aecbcfcf05eb3f.tar.gz
admin-7ed4760de47e51dc2148c6b1b4aecbcfcf05eb3f.zip
Conversion qt -> tqt
Signed-off-by: Michele Calgaro <michele.calgaro@yahoo.it>
Diffstat (limited to 'doxygen.sh')
-rwxr-xr-xdoxygen.sh68
1 files changed, 34 insertions, 34 deletions
diff --git a/doxygen.sh b/doxygen.sh
index 4b01c88..7fed793 100755
--- a/doxygen.sh
+++ b/doxygen.sh
@@ -82,33 +82,33 @@ fi
-### Sanity check and guess QTDOCDIR.
-if test -z "$QTDOCDIR" ; then
- if test -z "$QTDIR" ; then
- for i in /usr/X11R6/share/doc/qt/html
+### Sanity check and guess TQTDOCDIR.
+if test -z "$TQTDOCDIR" ; then
+ if test -z "$TQTDIR" ; then
+ for i in /usr/X11R6/share/doc/tqt/html
do
- QTDOCDIR="$i"
- test -d "$QTDOCDIR" && break
+ TQTDOCDIR="$i"
+ test -d "$TQTDOCDIR" && break
done
else
- for i in share/doc/qt/html doc/html
+ for i in share/doc/tqt/html doc/html
do
- QTDOCDIR="$QTDIR/$i"
- test -d "$QTDOCDIR" && break
+ TQTDOCDIR="$TQTDIR/$i"
+ test -d "$TQTDOCDIR" && break
done
fi
fi
-if test -z "$QTDOCDIR" || test ! -d "$QTDOCDIR" ; then
- if test -z "$QTDOCDIR" ; then
- echo "* QTDOCDIR could not be guessed."
+if test -z "$TQTDOCDIR" || test ! -d "$TQTDOCDIR" ; then
+ if test -z "$TQTDOCDIR" ; then
+ echo "* TQTDOCDIR could not be guessed."
else
- echo "* QTDOCDIR does not name a directory."
+ echo "* TQTDOCDIR does not name a directory."
fi
- if test -z "$QTDOCTAG" ; then
- echo "* QTDOCDIR set to \"\""
- QTDOCDIR=""
+ if test -z "$TQTDOCTAG" ; then
+ echo "* TQTDOCDIR set to \"\""
+ TQTDOCDIR=""
else
- echo "* But I'll use $QTDOCDIR anyway because of QTDOCTAG."
+ echo "* But I'll use $TQTDOCDIR anyway because of TQTDOCTAG."
fi
fi
@@ -562,7 +562,7 @@ apidox_subdir()
echo "TAGFILES = \\" >> "$subdir/Doxyfile"
## For now, don't support \ continued references lines
tags=`extract_line DOXYGEN_REFERENCES`
- for i in $tags qt ; do
+ for i in $tags tqt ; do
tagsubdir=`dirname $i` ; tag=`basename $i`
tagpath=""
not_found=""
@@ -609,15 +609,15 @@ apidox_subdir()
fi
fi
fi
- if test "$tag" = "qt" ; then
- if test -z "$QTDOCDIR" ; then
+ if test "$tag" = "tqt" ; then
+ if test -z "$TQTDOCDIR" ; then
echo " $file" >> "$subdir/Doxyfile"
else
if test -z "$file" ; then
# Really no Qt tags
echo "" >> "$subdir/Doxyfile"
else
- echo " $file=$QTDOCDIR" >> "$subdir/Doxyfile"
+ echo " $file=$TQTDOCDIR" >> "$subdir/Doxyfile"
fi
fi
else
@@ -845,18 +845,18 @@ if test "x." = "x$top_builddir" ; then
create_installdox > installdox-slow
if test "x$recurse" = "x1" ; then
if test "x$module_name" = "xtdelibs" ; then
- if test -z "$QTDOCTAG" && test -d "$QTDOCDIR" && \
- test ! -f "qt/qt.tag" ; then
- # Special case: create a qt tag file.
- echo "*** Creating a tag file for the Qt library:"
- mkdir qt
- doxytag -t qt/qt.tag "$QTDOCDIR" > /dev/null 2>&1
+ if test -z "$TQTDOCTAG" && test -d "$TQTDOCDIR" && \
+ test ! -f "tqt/tqt.tag" ; then
+ # Special case: create a tqt tag file.
+ echo "*** Creating a tag file for the TQt library:"
+ mkdir tqt
+ doxytag -t tqt/tqt.tag "$TQTDOCDIR" > /dev/null 2>&1
fi
fi
- if test -n "$QTDOCTAG" && test -r "$QTDOCTAG" ; then
- echo "*** Copying tag file for the Qt library:"
- mkdir qt
- cp "$QTDOCTAG" qt/qt.tag
+ if test -n "$TQTDOCTAG" && test -r "$TQTDOCTAG" ; then
+ echo "*** Copying tag file for the TQt library:"
+ mkdir tqt
+ cp "$TQTDOCTAG" tqt/tqt.tag
fi
do_subdirs_re "."
@@ -875,8 +875,8 @@ fi
if test "YES" = "$cleanup" ; then
rm -f subdirs.in subdirs.later subdirs.sort subdirs.top Doxyfile.in
rm -f `find . -name Doxyfile`
- rm -f qt/qt.tag
- rmdir qt > /dev/null 2>&1
+ rm -f tqt/tqt.tag
+ rmdir tqt > /dev/null 2>&1
fi
@@ -609,15 +609,15 @@ apidox_subdir()
else
if test -z "$file" ; then
- # Really no Qt tags
+ # Really no TQt tags
echo "" >> "$subdir/Doxyfile"
else